@@ -1,14 +1,19 @@
 #' Get the UID codes from NCBI for species names.
 #' 
-#' A function to retrieve the UID-Code (Unique Identifier) of a species from NCBI taxonomy browser.
+#' Retrieve the Unique Identifier (UID) of a species from NCBI taxonomy browser.
 #' 
 #' @import plyr RCurl
 #' @param sciname character; scientific name.
-#' @param verbose logical; If TRUE the actual taxon queried is printed on the console.
-#' @return UID for the supplied species names. NA for non-matching names.
+#' @param verbose logical; If TRUE the actual taxon queried is printed on the 
+#'    console.
+#' 
+#' @return A vector of unique identifiers (UID). If a species is not found NA. 
+#' If more than one UID is found the function asks for user input. 
+#' 
+#' @seealso \code{\link[taxize]{get_tsn}}, \code{\link[taxize]{classification}}
 #' 
 #' @export
-#' @author Eduard Szoecs \email{szoe8822@@uni-landau.de}
+#' @author Eduard Szoecs, \email{szoe8822@@uni-landau.de}
 #' 
 #' @examples \dontrun{
 #' get_uid(c("Chironomus riparius", "Chaetopteryx"))
@@ -17,7 +22,7 @@
 get_uid <- function(sciname, verbose = TRUE){
   fun <- function(sciname) {
     if(verbose)
-      cat("\nRetrieving data for species '", sciname, "'\n")
+      message("\nRetrieving data for species '", sciname, "'\n")
     sciname <- gsub(" ", "+", sciname)
     searchurl <- paste("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi?db=taxonomy&term=", 
                        sciname, sep = "")
@@ -41,8 +46,8 @@ get_uid <- function(sciname, verbose = TRUE){
       rownames(df) <- 1:nrow(df)
       
       # prompt
-      cat("\n\n")
-      cat("\nMore than one UID found for species '", sciname, "'!\n
+      message("\n\n")
+      message("\nMore than one UID found for species '", sciname, "'!\n
           Enter rownumber of species (other inputs will return 'NA'):\n")      
       print(df)
       take <- scan(n = 1, quiet = TRUE, what = 'raw')
@@ -51,11 +56,11 @@ get_uid <- function(sciname, verbose = TRUE){
         take <- 'notake'
       if(take %in% seq_len(nrow(df))){
         take <- as.numeric(take)
-        cat("Input accepted, took UID '", as.character(df$UID[take]), "'.\n")
+        message("Input accepted, took UID '", as.character(df$UID[take]), "'.\n")
         id <- as.character(df$UID[take])
       } else {
         id <- NA
-        cat("\nReturned 'NA'!\n\n")
+        message("\nReturned 'NA'!\n\n")
       }
     }  
     return(id)
