@@ -1,15 +1,17 @@
 #' Retrieve taxonomic rank name from given TSN.
 #' 
-#' @import ritis
 #' @param query Quoted TSN for a taxonomic group (numeric), or scientific
 #' 		name (character).
 #' @details You can print informative messages by setting supmess=FALSE.
 #' @return Taxonomic rank name.
 #' @examples \dontrun{
-#' itis_taxrank(202385)
+#' itis_taxrank(query=202385)
 #' }
 #' @export
 itis_taxrank <- function(query = NULL)
 {
-	as.character(gettaxonomicranknamefromtsn(query)$rankName)
+# 	searchtype <- "gettaxonomicranknamefromtsn"
+# 	as.character(gettaxonomicranknamefromtsn(query)$rankName)
+# 	itis(query=query, searchtype="gettaxonomicranknamefromtsn")$rankName	
+	ldply(query, gettaxonomicranknamefromtsn)$rankName
 }
\ No newline at end of file
